@@ -5,10 +5,10 @@ package Log::Any::Adapter::Log4perl;
 # ABSTRACT: Log::Any adapter for Log::Log4perl
 
 use Log::Log4perl 1.32; # bug-free wrapper_register available
-use Log::Any::Adapter::Util qw(make_method);
+use Log::Any::Adapter::Util 1.03 qw(make_method);
 use base qw(Log::Any::Adapter::Base);
 
-our $VERSION = '0.07';
+our $VERSION = '0.09';
 
 # Ensure %F, %C, etc. skip Log::Any related packages
 Log::Log4perl->wrapper_register(__PACKAGE__);
@@ -40,6 +40,16 @@ foreach my $method ( Log::Any->logging_and_detection_methods() ) {
     );
 }
 
+sub structured {
+    my ($adapter, $level, $category, @parts) = @_;
+    my $context = ref($parts[-1]) eq 'HASH'
+        ? pop @parts
+        : {};
+    my $mdc = Log::Log4perl::MDC->get_context;
+    local @{$mdc}{keys %{$context}} = values %{$context};
+    $adapter->$level(@parts);
+}
+
 1;
 
 __END__
@@ -54,7 +64,7 @@ Log::Any::Adapter::Log4perl - Log::Any adapter for Log::Log4perl
 
 =head1 VERSION
 
-version 0.07
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -80,6 +90,12 @@ Log levels are translated from Log::Any to Log4perl as follows:
     alert -> fatal
     emergency -> fatal
 
+=head1 METHODS
+
+=head2 structured
+
+This adapter supports structured logging, introduced in Log-Any v1.700.
+
 =head1 SEE ALSO
 
 =over 4
@@ -105,7 +121,7 @@ L<Log::Log4perl>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/dagolden/Log-Any-Adapter-Log4perl/issues>.
+at L<https://github.com/preaction/Log-Any-Adapter-Log4perl/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -113,9 +129,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/dagolden/Log-Any-Adapter-Log4perl>
+L<https://github.com/preaction/Log-Any-Adapter-Log4perl>
 
-  git clone https://github.com/dagolden/Log-Any-Adapter-Log4perl.git
+  git clone https://github.com/preaction/Log-Any-Adapter-Log4perl.git
 
 =head1 AUTHORS
 
@@ -129,11 +145,31 @@ Jonathan Swartz <swartz@pobox.com>
 
 David Golden <dagolden@cpan.org>
 
+=item *
+
+Doug Bell <preaction@cpan.org>
+
+=back
+
+=head1 CONTRIBUTORS
+
+=for stopwords Doug Bell Gianni Ceccarelli
+
+=over 4
+
+=item *
+
+Doug Bell <doug@preaction.me>
+
+=item *
+
+Gianni Ceccarelli <gianni.ceccarelli@broadbean.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jonathan Swartz.
+This software is copyright (c) 2018 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
